__title__ = 'lupro'
__description__ = 'Elegant reptile frame for python.'
__url__ = 'https://github.com/luxuncang/lupro'
__version__ = '1.0.7'
__author__ = 'ShengXin Lu'
__author_email__ = 'luxuncang@qq.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2021 ShengXin Lu'